@@ -5,12 +5,11 @@ def main():
     import sys
     if len(sys.argv[1:]) != 2:
         exit(1)
-    from base64 import b64decode, b64encode
-    key = b64decode(sys.argv[1])
+    key = sys.argv[1]
     content = sys.argv[2]
-    if b"PUBLIC KEY" in key:
+    if b"PUBLIC KEY" in b64decode(key):
         p(b64encode(EasyRSA(public_key=key).encrypt(content)).decode("utf-8"))
-    elif b"PRIVATE KEY" in key:
+    elif b"PRIVATE KEY" in b64decode(key):
         p(EasyRSA(private_key=key).decrypt(content))
     else:
         exit(1)
